##  Step 1: Create a SAML Application
Follow these steps:
  1. In the PingOne admin dashboard, in the Applications section, click Add Application.
  2. Enter a name for your application.
  3. Select SAML Application as the application type, then click Configure.
![Creating a SAML Application in PingIdentity](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d56307a441014beb78b787ae5639b_LowRes.png)
Creating a SAML Application in the PingOne Admin Dashboard
